@@ -359,22 +359,26 @@ notebook_help = [
        _('Put ?? after the object and press tab or shift-enter (shift-enter overwrites output and saves to worksheet).')),
       (_('Full Text Search of Docs and Source'),
        _('Search the SAGE documentation by typing <pre>search_doc("my query")</pre> in an input cell and press shift-enter.  Search the source code of SAGE by typing <pre>search_src("my query")</pre> and pressing shift-enter.  Arbitrary regular expressions are allowed as queries.')),
+      (_('Live Documentation'),
+       _('Use <a href="/doc/live/index.html">live documentation</a> to try out the full Sage documentation "live". (Only new compute cells allowed, click the icon.)')),
       # ('More Help',
       #  'Type "help(sagenb.notebook.notebook)" for a detailed discussion of the architecture of the SAGE notebook and a tutorial (or see the SAGE reference manual).'),
       ]),
     (_('Key and Mouse Bindings'),
      [(_('Evaluate Input'),
-       _('Press <strong>shift-enter</strong>.  You can start several calculations at once.  If you press <strong>alt-enter</strong> instead, then a new cell is created after the current one.  If you press <strong>ctrl-enter</strong> then the cell is split and both pieces are evaluated separately.')),
+       _('Press <strong>shift-enter</strong> or click the "evaluate" button.  You can start several calculations at once.  If you press <strong>alt-enter</strong> instead, then a new cell is created after the current one.  If you press <strong>ctrl-enter</strong> then the cell is split and both pieces are evaluated separately.')),
       (_('Tab Completion'),
        _('Press <strong>tab</strong> while the cursor is on an identifier. On some web browsers (e.g., Opera) you must use control-space instead of tab.')),
       (_('Insert New Cell'),
-       _('Put the mouse between an output and input until the horizontal line appears and click.  If you press Alt-Enter in a cell, the cell is evaluated and a new cell is inserted after it.')),
+       _('Put the mouse between an output and input until the blue horizontal line appears and click, or click the "plus" icon.  If you press Alt-Enter in a cell, the cell is evaluated and a new cell is inserted after it.')),
       (_('Delete Cell'),
        _('Delete all cell contents, then press <strong>backspace</strong>.')),
       (_('Split and Join Cells'),
        _('Press <strong>ctrl-;</strong> in a cell to split it into two cells, and <strong>ctrl-backspace</strong> to join them.  Press <strong>ctrl-enter</strong> to split a cell and evaluate both pieces.')),
       (_('Insert New Text Cell'),
-       _('Move the mouse between cells until a blue bar appears.  <strong>Shift-click</strong> on the blue bar to create a new text cell.  Double click on existing text to edit it.  Use $...$ and $$...$$ to include typeset math in the text block.')),
+       _('Move the mouse between cells until a blue bar appears.  <strong>Shift-click</strong> on the blue bar, or click on the text bubble icon, to create a new text cell.  Use $...$ and $$...$$ to include typeset math in the text block.  Click the button to save changes, or press <strong>shift-enter</strong>.')),
+      (_('Edit Text Cell'),
+       _('Double click on existing text to edit it.')),
       (_('Hide/Show Output'),
        _('Click on the left side of output to toggle between hidden, shown with word wrap, and shown without word wrap.')),
       (_('Indenting Blocks'),
@@ -415,7 +419,7 @@ notebook_help = [
      [(_('Loading SAGE/Python Scripts'),
        _('Use "load filename.sage" and "load filename.py".  Load is relative to the path you started the notebook in.  The .sage files are preparsed and .py files are not.   You may omit the .sage or .py extension.  Files may load other files.')),
       (_('Attaching Scripts'),
-       _('Use "attach filename.sage" or "attach filename.py".  Attached files are automatically reloaded when the file changes.  The file $HOME/.sage/init.sage is attached on startup if it exists.')),
+       _('(Currently no different from "load", see <a href="https://github.com/sagemath/sagenb/issues/169" target="_blank">bug report</a>) Use "attach filename.sage" or "attach filename.py".  Attached files are automatically reloaded when the file changes.  The file $HOME/.sage/init.sage is attached on startup if it exists.')),
       (_('Working Directory'),
        _('Each block of code is run from its own directory.  If any images are created as a side effect, they will automatically be displayed.')),
       (_('DIR Variable'),
